// $Id: global_vars.h,v 1.3 2010/11/17 12:07:54 swaj Exp $

#ifndef __GLOBAL_VARS_H__
#define __GLOBAL_VARS_H__ 1

#include <mega164.h>
#include "config.h"

/* timer0 -> 50Hz  divider */ 
#define TIMER0_INTR_RATE 50 

/* ticks to confirm keypress 50 = 1s  */ 
#define KEYBOARD_REPEATS 3
#define KEYBOARD_REPEATS_SET 150
#define KEYBOARD_INACTIVITY 10
#define KEYBOARD_INACTIVITY_SET 50


#define KEY_NOKEY	'N'
#define KEY_1		'1'
#define KEY_2		'2'
#define KEY_3		'3'
#define KEY_2_3		'4'


#undef VAR_DECL
#ifdef __DEF_GLOBAL_VARS__
#define VAR_DECL
#else  // ! __DEF_GLOBAL_VARS__
#define VAR_DECL extern
#endif


#define MAX_DS1820 1
#define DS1820_ROM_LEN 9
#define ATTEMPTS_SEARCH_DS1820 30

VAR_DECL int16_t temps[MAX_DS1820];

#define TEMP_FAILURES_MAX 30


// valid -70C ... +70C
#define TEMP_MIN	-70
#define TEMP_MAX	70
#define TEMP_INVALID	-99

#define TEMP_VALID(__t) ( (__t > (TEMP_MIN) ) && (__t < (TEMP_MAX)))

#define PIPE_TEMP_MIN_DFL	2
#define PIPE_TEMP_MAX_DFL	5

#define PIPE_TEMP_MIN	1
#define PIPE_TEMP_MAX	50

VAR_DECL eeprom int16_t pipe_temp_min;
VAR_DECL eeprom int16_t pipe_temp_max;


// -------------------- SYSTEM VARS ---------------
VAR_DECL volatile uint8_t ds1820_rom_codes[MAX_DS1820][DS1820_ROM_LEN];

VAR_DECL volatile uint8_t keyboard_repeats_set;

VAR_DECL volatile uint8_t anim_cntr;

VAR_DECL volatile uint8_t temp_failures;
VAR_DECL volatile uint8_t ds1820_devices;

VAR_DECL int16_t temps[MAX_DS1820];

VAR_DECL volatile uint8_t timer0_cntr;
VAR_DECL volatile uint8_t last_keyscan;
VAR_DECL volatile uint8_t last_keyscan_repeat;
VAR_DECL volatile uint8_t last_key;
VAR_DECL volatile uint8_t kbd_inactiv_timer;


/*

VAR_DECL volatile uint8_t t_sec;
VAR_DECL volatile uint8_t t_min;
VAR_DECL volatile uint8_t t_hrs;
VAR_DECL volatile uint16_t t_day;
*/

// --------------------- TIMERS ----------------

// -- 16 BIT
#define TIMER_INPUT		0
#define TIMER_TEMP		1
#define TIMER_MENU		2
#define TIMER_BND		3

#define TIMERS_MAX		4


VAR_DECL volatile uint16_t timers[TIMERS_MAX];


#define TIMER_TEMP_DFL		21	// temp every 30 s
#define TIMER_MENU_DFL		15	// 15 s
#define TIMER_BND_DFL           5

// ---------------------- FLAGS -------------------
VAR_DECL volatile uint8_t flg_ds1820_enabled;


// ---------------------- MISC ----------------------
#define TEMP_BUF_MAX 160
VAR_DECL volatile uint8_t temp_buf[TEMP_BUF_MAX+1];


#ifndef __DEF_GLOBAL_VARS__
extern flash const char fmt_crlf[];
#endif // __DEF_GLOBAL_VARS__


#undef VAR_DECL
#endif __GLOBAL_VARS_H__



/* __END__ */
